@@ -168,7 +168,6 @@ struct prop_info {
 #define STRING_PROP(fid,a) {fid, a, PROP_TYPE_STRING}
 #define GROUP_PROP(fid,a,ctor) {fid, a, PROP_TYPE_GROUP, ctor}
 
-
 	/* name fields */
 	STRING_PROP   (E_CONTACT_FULL_NAME,   "displayName" ),
 	STRING_PROP   (E_CONTACT_GIVEN_NAME,  "givenName" ),
@@ -763,7 +762,6 @@ contact_list_dtor (LDAPOp *op)
 	g_free (contact_list_op);
 }
 
-
 static void
 get_contact_list (EBookBackend *backend,
 		  EDataBook    *book,
@@ -878,7 +876,6 @@ get_contact_list (EBookBackend *backend,
 	}
 }
 
-
 #define IS_RFC2254_CHAR(c) ((c) == '*' || (c) =='\\' || (c) == '(' || (c) == ')' || (c) == '\0')
 static gchar *
 rfc2254_escape(gchar *str)
@@ -1016,7 +1013,6 @@ query_prop_to_ldap (const gchar *query_prop)
 	return NULL;
 }
 
-
 static ESExpResult *
 func_contains(ESExp *f, gint argc, ESExpResult **argv, gpointer data)
 {
@@ -1369,7 +1365,6 @@ last_mod_time_populate (EContact *contact, gchar **values,
 	g_free (time_str);
 }
 
-
 typedef struct {
 	LDAPOp op;
 	EDataBookView *view;
@@ -1735,7 +1730,6 @@ get_contacts_from_cache (EBookBackendGAL *ebg,
 	for (i = 0; i < ids->len; i ++) {
 		gchar *uid = g_ptr_array_index (ids, i);
 
-
 		EContact *contact =
 			e_book_backend_db_cache_get_contact (ebg->priv->file_db, uid);
 		if (contact) {
@@ -1822,7 +1816,6 @@ start_book_view (EBookBackend  *backend,
 				return;
 			}
 
-
 			contacts = e_book_backend_db_cache_get_contacts (bl->priv->file_db,
 									 e_data_book_view_get_card_query (view));
 			for (l = contacts; l;l = g_list_next (l)) {
@@ -2230,7 +2223,6 @@ generate_cache (EBookBackendGAL *book_backend_gal, const gchar * changed_filter)
 	build_query (book_backend_gal,
 		     "(beginswith \"file_as\" \"\")", changed_filter, &ldap_query);
 
-
 getNextPage:
 
 	/*start iteration*/
@@ -2265,7 +2257,6 @@ getNextPage:
 
 	rc = dosearch (book_backend_gal, LDAP_ROOT_DSE, LDAP_SCOPE_SUBTREE, NULL, ldap_query, NULL, 0, NULL, NULL, NULL, changed_filter, -1);
 
-
 	/* loop to get the next set of entries */
 
 	if ( (pageSize !=0 ) && (morePagedResults != 0)) {
@@ -2303,8 +2294,10 @@ update_cache (EBookBackendGAL *gal)
 		t1 = atoi (t);
 	else
 		t1=0;
-	if (t1 == 0)
-		return generate_cache (gal, NULL);
+	if (t1 == 0) {
+		generate_cache (gal, NULL);
+		return;
+	}
 	gal->priv->last_best_time = t1;
 	tm = localtime (&t1);
 	galtime = g_strdup_printf("%04d%02d%02d%02d%02d%02d.0Z",tm->tm_year+1900, tm->tm_mon+1,tm->tm_mday, tm->tm_hour, tm->tm_min, tm->tm_sec);
@@ -2406,7 +2399,6 @@ authenticate_user (EBookBackend *backend,
 		break;
 	}
 
-
 	/* We should not be here */
 	e_data_book_respond_authenticate_user (book,
 					       opid,
@@ -2832,7 +2824,6 @@ dispose (GObject *object)
 		if (bl->priv->ldap_lock)
 			g_mutex_free (bl->priv->ldap_lock);
 
-
 		g_free (bl->priv->gal_uri);
 		g_free (bl->priv);
 		bl->priv = NULL;
